@@ -27,16 +27,17 @@ from drf_spectacular.extensions import (
 from drf_spectacular.plumbing import (
     ComponentRegistry, ResolvedComponent, UnableToProceedError, append_meta,
     assert_basic_serializer, build_array_type, build_basic_type, build_choice_field,
-    build_examples_list, build_generic_type, build_media_type_object, build_object_type,
-    build_parameter_type, error, follow_field_source, follow_model_field_lookup, force_instance,
-    get_doc, get_type_hints, get_view_model, is_basic_serializer, is_basic_type, is_field,
-    is_list_serializer, is_patched_serializer, is_serializer, is_trivial_string_variation,
+    build_examples_list, build_generic_type, build_listed_example_value, build_media_type_object,
+    build_mocked_view, build_object_type, build_parameter_type, error, follow_field_source,
+    follow_model_field_lookup, force_instance, get_doc, get_type_hints, get_view_model,
+    is_basic_serializer, is_basic_type, is_field, is_list_serializer, is_patched_serializer,
+    is_serializer, is_trivial_string_variation, modify_media_types_for_versioning,
     resolve_django_path_parameter, resolve_regex_path_parameter, resolve_type_hint, safe_ref,
     sanitize_specification_extensions, warn, whitelisted,
 )
 from drf_spectacular.settings import spectacular_settings
 from drf_spectacular.types import OpenApiTypes
-from drf_spectacular.utils import OpenApiParameter, OpenApiResponse
+from drf_spectacular.utils import OpenApiCallback, OpenApiParameter, OpenApiResponse
 
 
 class AutoSchema(ViewInspector):
@@ -65,6 +66,10 @@ class AutoSchema(ViewInspector):
         if summary:
             operation['summary'] = summary
 
+        external_docs = self._get_external_docs()
+        if external_docs:
+            operation['externalDocs'] = external_docs
+
         parameters = self._get_parameters()
         if parameters:
             operation['parameters'] = parameters
@@ -91,6 +96,10 @@ class AutoSchema(ViewInspector):
         if extensions:
             operation.update(sanitize_specification_extensions(extensions))
 
+        callbacks = self._get_callbacks()
+        if callbacks:
+            operation['callbacks'] = callbacks
+
         return operation
 
     def _is_list_view(self, serializer=None):
@@ -254,6 +263,17 @@ class AutoSchema(ViewInspector):
         """ override this for custom behaviour """
         return None
 
+    def _get_external_docs(self):
+        external_docs = self.get_external_docs()
+        if isinstance(external_docs, str):
+            return {'url': external_docs}
+        else:
+            return external_docs
+
+    def get_external_docs(self):
+        """ override this for custom behaviour """
+        return None
+
     def get_auth(self):
         """
         Obtains authentication classes and permissions from view. If authentication
@@ -322,6 +342,68 @@ class AutoSchema(ViewInspector):
     def get_extensions(self) -> typing.Dict[str, typing.Any]:
         return {}
 
+    def _get_callbacks(self):
+        """
+        Creates a mocked view for every callback. The given extend_schema decorator then
+        specifies the expectations on the receiving end of the callback. Effectively
+        simulates a sub-schema from the opposing perspective via a virtual view definition.
+        """
+        result = {}
+
+        for callback in self.get_callbacks():
+            if isinstance(callback.decorator, dict):
+                methods = callback.decorator
+            else:
+                methods = {'post': callback.decorator}
+
+            path_items = {}
+
+            for method, decorator in methods.items():
+                # a dict indicates a raw schema; use directly
+                if isinstance(decorator, dict):
+                    path_items[method.lower()] = decorator
+                    continue
+
+                mocked_view = build_mocked_view(
+                    method=method,
+                    path=callback.path,
+                    extend_schema_decorator=decorator,
+                    registry=self.registry
+                )
+                operation = {}
+
+                description = mocked_view.schema.get_description()
+                if description:
+                    operation['description'] = description
+
+                summary = mocked_view.schema.get_summary()
+                if summary:
+                    operation['summary'] = summary
+
+                request_body = mocked_view.schema._get_request_body()
+                if request_body:
+                    operation['requestBody'] = request_body
+
+                deprecated = mocked_view.schema.is_deprecated()
+                if deprecated:
+                    operation['deprecated'] = deprecated
+
+                operation['responses'] = mocked_view.schema._get_response_bodies()
+
+                extensions = mocked_view.schema.get_extensions()
+                if extensions:
+                    operation.update(sanitize_specification_extensions(extensions))
+
+                path_items[method.lower()] = operation
+
+            result[callback.name] = {callback.path: path_items}
+
+        return result
+
+    def get_callbacks(self) -> typing.List[OpenApiCallback]:
+        """ override this for custom behaviour """
+        return []
+
     def get_operation_id(self):
         """ override this for custom behaviour """
         tokenized_path = self._tokenize_path()
@@ -656,7 +738,7 @@ class AutoSchema(ViewInspector):
                 content = {**build_basic_type(OpenApiTypes.STR), 'format': 'decimal'}
                 if field.max_whole_digits:
                     content['pattern'] = (
-                        fr'^\d{{0,{field.max_whole_digits}}}'
+                        fr'^-?\d{{0,{field.max_whole_digits}}}'
                         fr'(?:\.\d{{0,{field.decimal_places}}})?$'
                     )
             else:
@@ -673,7 +755,7 @@ class AutoSchema(ViewInspector):
             return append_meta(content, meta)
 
         if isinstance(field, serializers.FloatField):
-            content = build_basic_type(OpenApiTypes.FLOAT)
+            content = build_basic_type(OpenApiTypes.DOUBLE)
             self._insert_min_max(field, content)
             return append_meta(content, meta)
 
@@ -1031,6 +1113,8 @@ class AutoSchema(ViewInspector):
         # don't let the parameter examples influence the serializer example retrieval
         examples = [e for e in self.get_examples() if not e.parameter_only]
 
+        # Examples from Serializers via @extend_schema_serializer are only considered, if
+        # there were no higher priority examples directly from view annotation.
         if not examples:
             if is_list_serializer(serializer):
                 examples = get_override(serializer.child, 'examples', [])
@@ -1050,6 +1134,15 @@ class AutoSchema(ViewInspector):
                 continue
             if status_code and status_code not in example.status_codes:
                 continue
+
+            if (
+                self._is_list_view(serializer)
+                and get_override(serializer, 'many') is not False
+            ):
+                # contain modification to this context so "listing" is not propagated elsewhere
+                example = copy.copy(example)
+                example.value = build_listed_example_value(example.value, self._get_paginator(), direction)
+
             filtered_examples.append(example)
 
         return build_examples_list(filtered_examples)
@@ -1247,6 +1340,8 @@ class AutoSchema(ViewInspector):
         if not media_types:
             media_types = self.map_renderers('media_type')
 
+        media_types = modify_media_types_for_versioning(self.view, media_types)
+
         return {
             **headers,
             'content': {
@@ -1329,6 +1424,13 @@ class AutoSchema(ViewInspector):
         if direction == 'request' and spectacular_settings.COMPONENT_SPLIT_REQUEST:
             name = name + 'Request'
 
+        if not re.match(r'^[\w.-]+$', name):
+            warn(
+                f'Component name "{name}" contains illegal characters. Only "A-Z a-z 0-9 - . _" '
+                f'are allowed. Furthermore, "-" and "." are discoursed due to potential tooling '
+                f'issues. This likely leads to an invalid schema.'
+            )
+
         return name
 
     def resolve_serializer(self, serializer, direction) -> ResolvedComponent:
