@@ -33,6 +33,7 @@ from django.utils.functional import Promise, cached_property
 from django.utils.module_loading import import_string
 from django.utils.translation import gettext_lazy as _
 from rest_framework import exceptions, fields, mixins, serializers, versioning
+from rest_framework.compat import unicode_http_header
 from rest_framework.settings import api_settings
 from rest_framework.test import APIRequestFactory
 from rest_framework.utils.mediatypes import _MediaType
@@ -143,6 +144,8 @@ def get_lib_doc_excludes():
     # -> plumbing.py -> DRF views -> DRF DefaultSchema -> openapi.py - plumbing.py -> Loop
     from rest_framework import generics, views, viewsets
     return [
+        object,
+        dict,
         views.APIView,
         *[getattr(serializers, c) for c in dir(serializers) if c.endswith('Serializer')],
         *[getattr(viewsets, c) for c in dir(viewsets) if c.endswith('ViewSet')],
@@ -888,7 +891,7 @@ def modify_for_versioning(patterns, method, path, view, requested_version):
     elif issubclass(view.versioning_class, versioning.NamespaceVersioning):
         try:
             view.request.resolver_match = get_resolver(
-                urlconf=tuple(detype_pattern(p) for p in patterns)
+                urlconf=detype_patterns(tuple(patterns)),
             ).resolve(path)
         except Resolver404:
             error(f"namespace versioning path resolution failed for {path}. Path will be ignored.")
@@ -897,7 +900,7 @@ def modify_for_versioning(patterns, method, path, view, requested_version):
         # e.g "application/json; version=1.0"
         # To allow the AcceptHeaderVersioning negotiator going through.
         if not hasattr(view.request, 'accepted_renderer'):
-            # Probably a mock request, content negotation was not performed, so, we do it now.
+            # Probably a mock request, content negotiation was not performed, so, we do it now.
             negotiated = view.perform_content_negotiation(view.request)
             view.request.accepted_renderer, view.request.accepted_media_type = negotiated
         media_type = _MediaType(view.request.accepted_media_type)
@@ -908,6 +911,26 @@ def modify_for_versioning(patterns, method, path, view, requested_version):
     return path
 
 
+def modify_media_types_for_versioning(view, media_types: List[str]) -> List[str]:
+    if (
+        not view.versioning_class
+        or not issubclass(view.versioning_class, versioning.AcceptHeaderVersioning)
+    ):
+        return media_types
+
+    media_type = _MediaType(view.request.accepted_media_type)
+    version = media_type.params.get(view.versioning_class.version_param)  # type: ignore
+    version = unicode_http_header(version)
+
+    if not version or version == view.versioning_class.default_version:
+        return media_types
+
+    return [
+        f'{media_type}; {view.versioning_class.version_param}={version}'
+        for media_type in media_types
+    ]
+
+
 def analyze_named_regex_pattern(path):
     """ safely extract named groups and their pattern from given regex pattern """
     result = {}
@@ -953,6 +976,12 @@ def analyze_named_regex_pattern(path):
     return result
 
 
+@cache
+def detype_patterns(patterns):
+    """Cache detyped patterns due to the expensive nature of rebuilding URLResolver."""
+    return tuple(detype_pattern(pattern) for pattern in patterns)
+
+
 def detype_pattern(pattern):
     """
     return an equivalent pattern that accepts arbitrary values for path parameters.
@@ -1105,6 +1134,22 @@ def _get_type_hint_origin(hint):
         return origin, args
 
 
+def _resolve_typeddict(hint):
+    """resolve required fields for TypedDicts if on 3.9 or above"""
+    required = None
+
+    if sys.version_info >= (3, 9):
+        required = [h for h in hint.__required_keys__]
+
+    return build_object_type(
+        properties={
+            k: resolve_type_hint(v) for k, v in get_type_hints(hint).items()
+        },
+        required=required,
+        description=get_doc(hint),
+    )
+
+
 def resolve_type_hint(hint):
     """ resolve return value type hints to schema """
     origin, args = _get_type_hint_origin(hint)
@@ -1151,11 +1196,7 @@ def resolve_type_hint(hint):
             schema.update(build_basic_type(mixin_base_types[0]))
         return schema
     elif isinstance(hint, _TypedDictMeta):
-        return build_object_type(
-            properties={
-                k: resolve_type_hint(v) for k, v in get_type_hints(hint).items()
-            }
-        )
+        return _resolve_typeddict(hint)
     elif origin in UNION_TYPES:
         type_args = [arg for arg in args if arg is not type(None)]  # noqa: E721
         if len(type_args) > 1:
@@ -1178,3 +1219,46 @@ def whitelisted(obj: object, classes: List[Type[object]], exact=False):
         return obj.__class__ in classes
     else:
         return isinstance(obj, tuple(classes))
+
+
+def build_mocked_view(method: str, path: str, extend_schema_decorator, registry):
+    from rest_framework import parsers, views
+
+    @extend_schema_decorator
+    class TmpView(views.APIView):
+        parser_classes = [parsers.JSONParser]
+
+    # emulate what Generator would do to setup schema generation.
+    view_callable = TmpView.as_view()
+    view = view_callable.cls()  # type: ignore
+    view.request = spectacular_settings.GET_MOCK_REQUEST(
+        method.upper(), path, view, None
+    )
+    view.kwargs = {}
+    # prepare AutoSchema with "init" values as if get_operation() was called
+    view.schema.registry = registry
+    view.schema.path = path
+    view.schema.path_regex = path
+    view.schema.path_prefix = ''
+    view.schema.method = method.upper()
+    return view
+
+
+def build_listed_example_value(value: Any, paginator, direction):
+    if not paginator or direction == 'request':
+        return [value]
+
+    sentinel = object()
+    schema = paginator.get_paginated_response_schema(sentinel)
+    try:
+        return {
+            field_name: value if field_schema is sentinel else field_schema['example']
+            for field_name, field_schema in schema['properties'].items()
+        }
+    except (AttributeError, KeyError):
+        warn(
+            f"OpenApiExample could not be paginated because {paginator.__class__} either "
+            f"has an unknown schema structure or the individual pagination fields did not "
+            f"provide example values themselves. Using the plain example value as fallback."
+        )
+        return value
