@@ -1,12 +1,19 @@
 import inspect
+import sys
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, TypeVar, Union
 
+# direct import due to https://github.com/microsoft/pyright/issues/3025
+if sys.version_info >= (3, 8):
+    from typing import Final, Literal
+else:
+    from typing_extensions import Final, Literal
+
 from rest_framework.fields import Field, empty
 from rest_framework.serializers import Serializer
 from rest_framework.settings import api_settings
 
 from drf_spectacular.drainage import (
-    Final, Literal, error, get_view_method_names, isolate_view_method, set_override, warn,
+    error, get_view_method_names, isolate_view_method, set_override, warn,
 )
 from drf_spectacular.types import OpenApiTypes, _KnownPythonTypes
 
@@ -194,6 +201,36 @@ class OpenApiResponse(OpenApiSchemaBase):
 F = TypeVar('F', bound=Callable[..., Any])
 
 
+class OpenApiCallback(OpenApiSchemaBase):
+    """
+    Helper class to bundle a callback definition. This specifies a view on the callee's
+    side, effectively stating the expectations on the receiving end. Please note that this
+    particular :func:`@extend_schema <.extend_schema>` instance operates from the perspective
+    of the callback origin, which means that ``request`` specifies the outgoing request.
+
+    For convenience sake, we assume the callback sends ``application/json`` and return a ``200``.
+    If that is not sufficient, you can use ``request`` and ``responses`` overloads just as you
+    normally would.
+
+    :param name: Name under which the this callback is listed in the schema.
+    :param path: Path on which the callback operation is performed. To reference request
+        body contents, please refer to OpenAPI specification's
+        `key expressions <https://swagger.io/specification/#key-expression>`_ for valid choices.
+    :param decorator: :func:`@extend_schema <.extend_schema>` decorator that specifies the receiving
+        endpoint. In this special context the allowed parameters are ``requests``, ``responses``,
+        ``summary``, ``description``, ``deprecated``.
+    """
+    def __init__(
+            self,
+            name: str,
+            path: str,
+            decorator: Union[Callable[[F], F], Dict[str, Callable[[F], F]], Dict[str, Any]],
+    ):
+        self.name = name
+        self.path = path
+        self.decorator = decorator
+
+
 def extend_schema(
         operation_id: Optional[str] = None,
         parameters: Optional[List[Union[OpenApiParameter, _SerializerType]]] = None,
@@ -211,6 +248,8 @@ def extend_schema(
         versions: Optional[List[str]] = None,
         examples: Optional[List[OpenApiExample]] = None,
         extensions: Optional[Dict[str, Any]] = None,
+        callbacks: Optional[List[OpenApiCallback]] = None,
+        external_docs: Optional[Union[Dict[str, str], str]] = None,
 ) -> Callable[[F], F]:
     """
     Decorator mainly for the "view" method kind. Partially or completely overrides
@@ -258,6 +297,10 @@ def extend_schema(
     :param versions: scope extend_schema to specific API version. matches all by default.
     :param examples: attach request/response examples to the operation
     :param extensions: specification extensions, e.g. ``x-badges``, ``x-code-samples``, etc.
+    :param callbacks: associate callbacks with this endpoint
+    :param external_docs: Link external documentation. Provide a dict with an "url" key and
+        optionally a "description" key. For convenience, if only a string is given it is
+        treated as the URL.
     :return:
     """
     if methods is not None:
@@ -357,6 +400,16 @@ def extend_schema(
                     return getattr(self.view, 'filter_backends', []) if filters else []
                 return super().get_filter_backends()
 
+            def get_callbacks(self):
+                if callbacks is not None and is_in_scope(self):
+                    return callbacks
+                return super().get_callbacks()
+
+            def get_external_docs(self):
+                if external_docs is not None and is_in_scope(self):
+                    return external_docs
+                return super().get_external_docs()
+
         if inspect.isclass(f):
             # either direct decoration of views, or unpacked @api_view from OpenApiViewExtension
             if operation_id is not None or operation is not None:
@@ -497,7 +550,11 @@ def extend_schema_view(**kwargs) -> Callable[[F], F]:
             # the context of derived methods must not be altered, as it belongs to the
             # other view. create a new context so the schema can be safely stored in the
             # wrapped_method. view methods that are not derived can be safely altered.
-            method_decorator(isolate_view_method(view, method_name))
+            if hasattr(method_decorator, '__iter__'):
+                for sub_method_decorator in method_decorator:
+                    sub_method_decorator(isolate_view_method(view, method_name))
+            else:
+                method_decorator(isolate_view_method(view, method_name))
         return view
 
     return decorator
