@@ -1,4 +1,6 @@
-from rest_framework import serializers, viewsets
+import pytest
+from rest_framework import __version__ as DRF_VERSION  # type: ignore[attr-defined]
+from rest_framework import generics, pagination, serializers, viewsets
 from rest_framework.decorators import action
 from rest_framework.response import Response
 
@@ -154,3 +156,46 @@ def test_examples(no_warnings):
         generate_schema('schema', ExampleTestWithExtendedViewSet),
         'tests/test_examples.yml',
     )
+
+
+@pytest.mark.skipif(DRF_VERSION < '3.12', reason='DRF pagination schema broken')
+def test_example_pagination(no_warnings):
+    class PaginatedExamplesViewSet(ExampleTestWithExtendedViewSet):
+        pagination_class = pagination.LimitOffsetPagination
+
+    schema = generate_schema('e', PaginatedExamplesViewSet)
+    operation = schema['paths']['/e/']['get']
+    assert operation['responses']['200']['content']['application/json']['examples'] == {
+        'SerializerCExampleRO': {
+            'value': {
+                'count': 123,
+                'next': 'http://api.example.org/accounts/?offset=400&limit=100',
+                'previous': 'http://api.example.org/accounts/?offset=200&limit=100',
+                'results': {'field': 111}
+            },
+            'summary': 'Serializer C Example RO'
+        }
+    }
+
+
+def test_example_request_response_listed_examples(no_warnings):
+    @extend_schema(
+        request=ASerializer(many=True),
+        responses=ASerializer(many=True),
+        examples=[
+            OpenApiExample('Ex', {'id': '1234'})
+        ]
+    )
+    class XView(generics.CreateAPIView):
+        pass
+
+    schema = generate_schema('e', view=XView)
+    operation = schema['paths']['/e']['post']
+    assert operation['requestBody']['content']['application/json'] == {
+        'schema': {'type': 'array', 'items': {'$ref': '#/components/schemas/A'}},
+        'examples': {'Ex': {'value': [{'id': '1234'}]}}
+    }
+    assert operation['responses']['201']['content']['application/json'] == {
+        'schema': {'type': 'array', 'items': {'$ref': '#/components/schemas/A'}},
+        'examples': {'Ex': {'value': [{'id': '1234'}]}}
+    }
